@@ -2,22 +2,53 @@ import json
 from fcp.spec import *
 from fst_cantools import Message as CANmessage
 
+from math import *
+
 
 def bitmask(n):
     return 2 ** n - 1
 
+def test_bitmask():
+    assert 0xF == bitmask(4)
+
 
 def encode_signal(signal, value):
     value = (value - signal.offset) / signal.scale
     return (int(value) & bitmask(signal.length)) << signal.start
 
 
+def conv_endianess(value: int, signal: Signal):
+    length = signal.get_length()/8
+    log2_length = log2(length)
+    
+    if length == 1:
+        return value
+
+    if log2_length != int(log2_length):
+        return value
+
+    if signal.get_byte_order() != "big_endian":
+        return value
+
+    length = int(length)
+    def swap64(x):
+        return int.from_bytes(value.to_bytes(8, byteorder='little'), byteorder='big', signed=False)
+    def swap32(x):
+        return int.from_bytes(value.to_bytes(4, byteorder='little'), byteorder='big', signed=False)
+    def swap16(x):
+        return int.from_bytes(value.to_bytes(2, byteorder='little'), byteorder='big', signed=False)
+
+    if length == 8:
+        return swap64(value)
+    if length == 4:
+        return swap32(value) 
+    if length == 2:
+        return swap16(value)
+
+
 def decode_signal(signal, value):
     value = (value >> signal.start) & bitmask(signal.length)
-
-    #if "se" in signal.name:
-    #    print(signal)
-
+    value = conv_endianess(value, signal)
     if signal.type == 'signed':
         value = int(value)
         if (value >> (signal.length - 1)) == 1:
