@@ -49,10 +49,7 @@ def multiplexor(signal, message):
 
 def dst_type_decide(signal):
     if signal.scale != 1:
-        if signal.length == 32:
-            return "float"
-        elif signal.length == 64:
-            return "double"
+        return "float"
 
     if signal.type == "signed":
         if signal.length <= 8:
