@@ -20,12 +20,15 @@ from .gui_lib.messagedetails import Ui_MessageDetails
 from .gui_lib.signalwidget import Ui_SignalWidget
 from .gui_lib.signaldetails import Ui_SignalDetails
 from .gui_lib.logwidget import Ui_LogWidget
+from .gui_lib.enumwidget import Ui_EnumWidget
+from .gui_lib.enumdetails import Ui_EnumDetails
 from .gui_lib.logdetails import Ui_LogDetails
 from .gui_lib.cfgwidget import Ui_CfgWidget
 from .gui_lib.cfgdetails import Ui_CfgDetails
 from .gui_lib.cmdwidget import Ui_CmdWidget
 from .gui_lib.cmddetails import Ui_CmdDetails
 from .gui_lib.cmdarg import Ui_CmdArg
+from .gui_lib.enumvalue import Ui_EnumValue
 
 from datetime import datetime
 
@@ -88,6 +91,7 @@ class NodeDetails(QWidget):
 
     def reload(self):
         for child in self.children:
+            print("\t",child, flush=True)
             child.reload()
 
         for att, get_f, set_f in self.atts:
@@ -129,6 +133,7 @@ class SignalDetails(NodeDetails):
             (ui.byteOrderEdit, node.get_byte_order, node.set_byte_order),
             (ui.scaleEdit, node.get_scale, node.set_scale),
             (ui.offsetEdit, node.get_offset, node.set_offset),
+            (ui.aliasEdit, node.get_alias, node.set_alias)
         ]
 
     def __init__(self, gui, node: "Signal", parent):
@@ -177,6 +182,7 @@ class MessageDetails(NodeDetails):
             (ui.idEdit, node.get_id, node.set_id),
             (ui.dlcEdit, node.get_dlc, node.set_dlc),
             (ui.frequencyEdit, node.get_frequency, node.set_frequency),
+            (ui.descriptionEdit, node.get_description, node.set_description),
         ]
 
     def __init__(self, gui, node: "Message", parent):
@@ -318,6 +324,7 @@ class CmdWidget(QWidget):
 
     def reload(self):
         for child in self.children:
+            print("\t", child, flush=True)
             child.reload()
 
     def add_cmd(self, cmd=None):
@@ -394,6 +401,7 @@ class CfgWidget(QWidget):
 
     def reload(self):
         for child in self.children:
+            print("\t", child, flush=True)
             child.reload()
 
     def add_cfg(self, cfg=None):
@@ -513,6 +521,71 @@ class LogDetails(NodeDetails):
 
         self.children = []
 
+class EnumValueDetails(NodeDetails):
+    def load_atts(self, ui, node):
+        self.atts = [
+            (ui.valueEdit, node.get_value, node.set_value),
+            (ui.nameEdit, node.get_name, node.set_name),
+        ]
+
+    def __init__(self, gui, node, parent):
+        NodeDetails.__init__(self, gui, node, parent)
+
+        self.ui = Ui_EnumValue()
+        self.ui.setupUi(self)
+
+        self.load_atts(self.ui, node)
+        self.connect_atts()
+
+        self.ui.enumDeleteButton.clicked.connect(self.delete)
+
+        self.reload()
+        self.setVisible(True)
+
+        self.children = []
+
+
+class EnumDetails(NodeDetails):
+    def load_atts(self, ui, node):
+        self.atts = [
+            (ui.nameEdit, node.get_name, node.set_name),
+        ]
+
+    def __init__(self, gui, node, parent):
+        NodeDetails.__init__(self, gui, node, parent)
+
+        self.ui = Ui_EnumDetails()
+        self.ui.setupUi(self)
+
+        self.load_atts(self.ui, node)
+        self.connect_atts()
+
+        self.ui.enumDeleteButton.clicked.connect(self.delete)
+
+        self.reload()
+        self.setVisible(True)
+
+        self.children = []
+
+        self.ui.valueAddButton.clicked.connect(self.add_value)
+
+        for enum_value in node.enumeration.values():
+            self.add_value(enum_value)
+
+    def add_value(self, enum_value=None):
+        if enum_value == None or enum_value == False:
+            enum_value = EnumValue()
+
+        self.node.enumeration[enum_value.name] = enum_value
+        enum_widget = EnumValueDetails(self.gui, enum_value, FakeParent())
+        self.children.append(enum_widget)
+        self.ui.EnumValueContents.addWidget(enum_widget)
+        
+    def save(self):
+        for child in self.children:
+            child.save()
+
+        self.gui.reload()
 
 class LogWidget(QWidget):
     def __init__(self, gui, parent):
@@ -540,6 +613,7 @@ class LogWidget(QWidget):
         return
 
     def save(self):
+        print("Save log")
         for child in self.children:
             child.save()
 
@@ -554,6 +628,48 @@ class LogWidget(QWidget):
         self.ui.logContents.addWidget(log_widget)
         self.children.append(log_widget)
 
+class EnumWidget(QWidget):
+    def __init__(self, gui, parent):
+        self.Window = True
+        QWidget.__init__(self)
+        self.ui = Ui_EnumWidget()
+        self.ui.setupUi(self)
+
+        self.parent = parent
+        self.gui = gui
+
+        self.atts = []
+
+        self.children = []
+
+        self.reload()
+
+        self.details = None
+
+        self.ui.addEnumButton.clicked.connect(self.add_enum)
+        for enum in self.parent.enums.values():
+            self.add_enum(enum)
+
+    def reload(self):
+        for child in self.children:
+            child.reload()
+
+        return
+
+    def save(self):
+        for child in self.children:
+            child.save()
+
+        self.gui.reload()
+
+    def add_enum(self, enum=None):
+        if enum == None or enum == False:
+            enum = Enum()
+
+        self.parent.enums[enum.name] = enum
+        enum_widget = EnumDetails(self.gui, enum, FakeParent())
+        self.ui.enumContents.addWidget(enum_widget)
+        self.children.append(enum_widget)
 
 class Gui(QMainWindow):
     def __init__(self, logger):
@@ -578,9 +694,9 @@ class Gui(QMainWindow):
         shortcutOpen.activated.connect(self.open_json)
 
         self.ui.addButton.clicked.connect(self.add_device)
-        self.ui.logsButton.clicked.connect(self.open_log_widget)
 
         self.log_widget = None
+        self.enum_widget = None
 
     def open_log_widget(self, checked):
         if self.log_widget is None:
@@ -589,6 +705,13 @@ class Gui(QMainWindow):
 
         self.log_widget.setVisible(checked)
 
+    def open_enum_widget(self, checked):
+        if self.enum_widget is None:
+            print("enum not opened")
+            return
+        
+        self.enum_widget.setVisible(checked)
+
     def validate(self):
         msg = QMessageBox(self)
         msg.setStandardButtons(QMessageBox.Ok)
@@ -668,11 +791,15 @@ class Gui(QMainWindow):
         self.add_device(self.spec.common)
 
         self.log_widget = LogWidget(self, self.spec)
-        self.log_widget.setVisible(False)
+        self.log_widget.setVisible(True)
         self.ui.logDetailsLayout.addWidget(self.log_widget)
+        self.enum_widget = EnumWidget(self, self.spec)
+        self.enum_widget.setVisible(True)
+        self.ui.enumDetailsLayout.addWidget(self.enum_widget)
 
     def reload(self):
         for node in self.children:
+            print(node, flush=True)
             node.reload()
 
         self.spec.normalize()
